@@ -29,18 +29,15 @@ public:
   BackupPolicyInterval(): BackupPolicy("interval") {}
 
   void validate(const Volume *volume) const override {
-    if(parseTimeInterval(get(volume, "min-interval"), 1,
-                         std::numeric_limits<int>::max())
-       < 1)
+    if(parseTimeInterval(get(volume, "min-interval")) < 1)
       throw SyntaxError("min-interval too small");
   }
 
   bool backup(const Volume *volume, const Device *device) const override {
     time_t now = Date::now();
-    int minInterval = parseTimeInterval(get(volume, "min-interval"), 1,
-                                        std::numeric_limits<int>::max());
+    int minInterval = parseTimeInterval(get(volume, "min-interval"));
     for(const Backup *backup: volume->backups)
-      if(backup->rc == 0 && now - backup->time < minInterval
+      if(backup->getStatus() == COMPLETE && now - backup->time < minInterval
          && backup->deviceName == device->name)
         return false;
     return true;
