@@ -65,6 +65,7 @@ void Conf::write(std::ostream &os, int step, bool verbose) const {
   d(os, "", step);
 
   ConfBase::write(os, step, verbose);
+  writeHostCheck(os, step, verbose);
 
   d(os, "# ---- Non-inheritable directives ----", step);
   d(os, "", step);
@@ -435,23 +436,6 @@ void Conf::readState() {
   const bool progress = (globalWarningMask & WARNING_VERBOSE) && isatty(2);
   std::vector<std::string> upgraded;
 
-  // Detect old-format logfiles and error if present
-  if(boost::filesystem::exists(logs)) {
-    Directory::getFiles(logs, files);
-    std::regex logfileRegexp(
-        "^([0-9]+-[0-9]+-[0-9]+)-([^-]+)-([^-]+)-([^-]+)\\.log$");
-    int oldFiles = 0;
-    for(size_t n = 0; n < files.size(); ++n) {
-      std::smatch mr;
-      if(!std::regex_match(files[n], mr, logfileRegexp))
-        continue;
-      ++oldFiles;
-    }
-    if(oldFiles)
-      throw SystemError("old format logs exist, you must use a release between "
-                        "2.0 and 6.0 to upgrade");
-  }
-
   std::string log;
   // Read database contents
   // Better would be to read only the rows required, on demand.
@@ -469,7 +453,7 @@ void Conf::readState() {
       backup.id = stmt.get_string(3);
       backup.time = stmt.get_int64(4);
       backup.pruned = stmt.get_int64(5);
-      backup.rc = stmt.get_int(6);
+      backup.waitStatus = stmt.get_int(6);
       backup.setStatus(stmt.get_int(7));
       backup.contents = stmt.get_blob(8);
       addBackup(backup, hostName, volumeName);
@@ -585,15 +569,18 @@ Database &Conf::getdb() {
       try {
         db = new Database(globalDatabase, false);
       } catch(DatabaseError &) {
+        // If we cannot open the database even with -n then we
+        // create a throwaway in-memory database so that we can
+        // make some progress in showing what we'd do anyway.
         db = new Database(":memory:");
-        createTables();
+        createTables(true);
       }
     }
   }
   return *db;
 }
 
-void Conf::createTables() {
+void Conf::createTables(bool commitAnyway) {
   db->begin();
   db->execute("CREATE TABLE backup (\n"
               "  host TEXT,\n"
@@ -607,7 +594,7 @@ void Conf::createTables() {
               "  log BLOB,\n"
               "  PRIMARY KEY (host,volume,device,id)\n"
               ")");
-  db->commit();
+  db->commit(commitAnyway);
 }
 
 ConfBase *Conf::getParent() const {
