@@ -117,8 +117,9 @@ public:
 
   /** @brief rsync extra options */
   std::vector<std::string> rsyncExtraOptions = {
-      "--xattrs", // preserve extended attributes
-      "--acls",   // preserve ACLs
+      "--xattrs",       // preserve extended attributes
+      "--acls",         // preserve ACLs
+      "--open-noatime", // suppress atime changes
   };
 
   /** @brief rsync @c --rsync-path override */
@@ -155,6 +156,13 @@ public:
    */
   virtual void write(std::ostream &os, int step, bool verbose) const;
 
+  /** @brief Write the host-check configuration to a stream
+   * @param os Output stream
+   * @param step Indent depth
+   * @param verbose Include informative annotations
+   */
+  void writeHostCheck(std::ostream &os, int step, bool verbose) const;
+
   /** @brief Return the parent of this configuration node
    * @return Parent node or null pointer
    */
