@@ -294,9 +294,7 @@ static const struct RmDirective: public ConfDirective {
 
 /** @brief The @c pre-device-hook directive */
 static const struct PreDeviceHookDirective: public ConfDirective {
-  PreDeviceHookDirective(): ConfDirective("pre-device-hook", 1, INT_MAX) {
-    alias("pre-access-hook");
-  }
+  PreDeviceHookDirective(): ConfDirective("pre-device-hook", 1, INT_MAX) {}
   void set(ConfContext &cc) const override {
     cc.conf->preDevice.assign(cc.bits.begin() + 1, cc.bits.end());
   }
@@ -304,9 +302,7 @@ static const struct PreDeviceHookDirective: public ConfDirective {
 
 /** @brief The @c post-device-hook directive */
 static const struct PostDeviceHookDirective: public ConfDirective {
-  PostDeviceHookDirective(): ConfDirective("post-device-hook", 1, INT_MAX) {
-    alias("post-access-hook");
-  }
+  PostDeviceHookDirective(): ConfDirective("post-device-hook", 1, INT_MAX) {}
   void set(ConfContext &cc) const override {
     cc.conf->postDevice.assign(cc.bits.begin() + 1, cc.bits.end());
   }
@@ -316,8 +312,7 @@ static const struct PostDeviceHookDirective: public ConfDirective {
 static const struct KeepPruneLogsDirective: public ConfDirective {
   KeepPruneLogsDirective(): ConfDirective("keep-prune-logs", 1, 1) {}
   void set(ConfContext &cc) const override {
-    cc.conf->keepPruneLogs =
-        parseTimeInterval(cc.bits[1], 86400, std::numeric_limits<int>::max());
+    cc.conf->keepPruneLogs = parseTimeInterval(cc.bits[1]);
   }
 } keep_prune_logs_directive;
 
@@ -325,8 +320,7 @@ static const struct KeepPruneLogsDirective: public ConfDirective {
 static const struct PruneTimeoutDirective: public ConfDirective {
   PruneTimeoutDirective(): ConfDirective("prune-timeout", 1, 1) {}
   void set(ConfContext &cc) const override {
-    cc.conf->pruneTimeout =
-        parseTimeInterval(cc.bits[1], 1, std::numeric_limits<int>::max());
+    cc.conf->pruneTimeout = parseTimeInterval(cc.bits[1]);
   }
 } prune_timeout_directive;
 
@@ -501,8 +495,7 @@ static const struct GraphLayoutDirective: public ConfDirective {
 static const struct MaxAgeDirective: InheritableDirective {
   MaxAgeDirective(): InheritableDirective("max-age", 1, 1) {}
   void set(ConfContext &cc) const override {
-    cc.context->maxAge =
-        parseTimeInterval(cc.bits[1], 86400, std::numeric_limits<int>::max());
+    cc.context->maxAge = parseTimeInterval(cc.bits[1]);
   }
 } max_age_directive;
 
@@ -585,9 +578,7 @@ static const struct PruneParameterDirective: InheritableDirective {
 /** @brief The @c pre-volume-hook directive */
 static const struct PreVolumeHookDirective: InheritableDirective {
   PreVolumeHookDirective():
-      InheritableDirective("pre-volume-hook", 0, INT_MAX) {
-    alias("pre-backup-hook");
-  }
+      InheritableDirective("pre-volume-hook", 0, INT_MAX) {}
   void set(ConfContext &cc) const override {
     cc.context->preVolume.assign(cc.bits.begin() + 1, cc.bits.end());
   }
@@ -596,9 +587,7 @@ static const struct PreVolumeHookDirective: InheritableDirective {
 /** @brief The @c post-volume-hook directive */
 static const struct PostVolumeHookDirective: InheritableDirective {
   PostVolumeHookDirective():
-      InheritableDirective("post-volume-hook", 0, INT_MAX) {
-    alias("post-backup-hook");
-  }
+      InheritableDirective("post-volume-hook", 0, INT_MAX) {}
   void set(ConfContext &cc) const override {
     cc.context->postVolume.assign(cc.bits.begin() + 1, cc.bits.end());
   }
@@ -607,12 +596,9 @@ static const struct PostVolumeHookDirective: InheritableDirective {
 /** @brief The @c backup-job-timeout directive */
 static const struct BackupJobTimeoutDirective: InheritableDirective {
   BackupJobTimeoutDirective():
-      InheritableDirective("backup-job-timeout", 1, 1) {
-    alias("rsync-timeout");
-  }
+      InheritableDirective("backup-job-timeout", 1, 1) {}
   void set(ConfContext &cc) const override {
-    cc.context->backupJobTimeout =
-        parseTimeInterval(cc.bits[1], 1, std::numeric_limits<int>::max());
+    cc.context->backupJobTimeout = parseTimeInterval(cc.bits[1]);
   }
 } backup_job_directive;
 
@@ -620,8 +606,7 @@ static const struct BackupJobTimeoutDirective: InheritableDirective {
 static const struct RsyncIOTimeoutDirective: InheritableDirective {
   RsyncIOTimeoutDirective(): InheritableDirective("rsync-io-timeout", 1, 1) {}
   void set(ConfContext &cc) const override {
-    cc.context->rsyncIOTimeout =
-        parseTimeInterval(cc.bits[1], 1, std::numeric_limits<int>::max());
+    cc.context->rsyncIOTimeout = parseTimeInterval(cc.bits[1]);
   }
 } rsync_io_timeout_directive;
 
@@ -629,8 +614,7 @@ static const struct RsyncIOTimeoutDirective: InheritableDirective {
 static const struct HookTimeoutDirective: InheritableDirective {
   HookTimeoutDirective(): InheritableDirective("hook-timeout", 1, 1) {}
   void set(ConfContext &cc) const override {
-    cc.context->hookTimeout =
-        parseTimeInterval(cc.bits[1], 1, std::numeric_limits<int>::max());
+    cc.context->hookTimeout = parseTimeInterval(cc.bits[1]);
   }
 } hook_timeout_directive;
 
@@ -655,8 +639,7 @@ static const struct HostCheckDirective: InheritableDirective {
 static const struct SshTimeoutDirective: InheritableDirective {
   SshTimeoutDirective(): InheritableDirective("ssh-timeout", 1, 1) {}
   void set(ConfContext &cc) const override {
-    cc.context->sshTimeout =
-        parseTimeInterval(cc.bits[1], 1, std::numeric_limits<int>::max());
+    cc.context->sshTimeout = parseTimeInterval(cc.bits[1]);
   }
 } ssh_timeout_directive;
 
