@@ -191,7 +191,7 @@ public:
   void begin();
 
   /** @brief Commit a transaction */
-  void commit();
+  void commit(bool commitAnyway = false);
 
   /** @brief Abandon a transaction */
   void rollback();
@@ -201,7 +201,7 @@ public:
 
 private:
   /** @brief Underlying database handle */
-  sqlite3 *db;
+  sqlite3 *db = nullptr;
 
   /** @brief Raise an error
    * @param description Context for error
