@@ -39,14 +39,13 @@ static void runDeviceAccessHook(const std::vector<std::string> &cmd,
   }
   sp.setenv("RSBACKUP_DEVICES", devices);
   sp.reporting(globalWarningMask & WARNING_VERBOSE, false);
-  sp.runAndWait(Subprocess::THROW_ON_ERROR
-                |Subprocess::THROW_ON_CRASH
-                |Subprocess::THROW_ON_SIGPIPE);
+  sp.runAndWait(Subprocess::THROW_ON_ERROR | Subprocess::THROW_ON_CRASH
+                | Subprocess::THROW_ON_SIGPIPE);
 }
 
 void preDeviceAccess() {
   if(!devicesReady) {
-    runDeviceAccessHook(globalConfig.preAccess, "pre-access-hook");
+    runDeviceAccessHook(globalConfig.preDevice, "pre-device-hook");
     devicesReady = true;
   }
 }
@@ -58,7 +57,7 @@ void closeOnUnmount(IO *f) {
 void postDeviceAccess() {
   if(devicesReady) {
     deleteAll(filesToClose);
-    runDeviceAccessHook(globalConfig.postAccess, "post-access-hook");
+    runDeviceAccessHook(globalConfig.postDevice, "post-device-hook");
     devicesReady = false;
   }
 }
