@@ -21,10 +21,11 @@
 
 #include <string>
 #include <vector>
+#include <map>
 
 #include "Defaults.h"
 
-class Attachments;
+class RenderDocumentContext;
 
 /** @brief Structured document class
  *
@@ -53,14 +54,17 @@ public:
 
     /** @brief Render as HTML
      * @param os Output
-     * @param as Accumulator for attachments
+     * @param rc Rendering context
      */
-    virtual void renderHtml(std::ostream &os, Attachments *as) const = 0;
+    virtual void renderHtml(std::ostream &os,
+                            RenderDocumentContext *rc) const = 0;
 
     /** @brief Render as text
      * @param os Output
+     * @param rc Rendering context
      */
-    virtual void renderText(std::ostream &os) const = 0;
+    virtual void renderText(std::ostream &os,
+                            RenderDocumentContext *rc) const = 0;
 
     /** @brief Render an open tag
      * @param os Output
@@ -104,14 +108,15 @@ public:
 
     /** @brief Render as HTML
      * @param os Output
-     * @param as Accumulator for attachments
+     * @param rc Rendering context
      */
-    void renderHtml(std::ostream &os, Attachments *as) const override;
+    void renderHtml(std::ostream &os, RenderDocumentContext *rc) const override;
 
     /** @brief Render as text
      * @param os Output
+     * @param rc Rendering context
      */
-    void renderText(std::ostream &os) const override;
+    void renderText(std::ostream &os, RenderDocumentContext *rc) const override;
   };
 
   /** @brief Base class for ordered containers */
@@ -156,25 +161,27 @@ public:
 
     /** @brief Render as HTML
      * @param os Output
-     * @param as Accumulator for attachments
+     * @param rc Rendering context
      */
-    void renderHtmlContents(std::ostream &os, Attachments *as) const;
+    void renderHtmlContents(std::ostream &os, RenderDocumentContext *rc) const;
 
     /** @brief Render as text
      * @param os Output
+     * @param rc Rendering context
      */
-    void renderTextContents(std::ostream &os) const;
+    void renderTextContents(std::ostream &os, RenderDocumentContext *rc) const;
 
     /** @brief Render as HTML
      * @param os Output
-     * @param as Accumulator for attachments
+     * @param rc Rendering context
      */
-    void renderHtml(std::ostream &os, Attachments *as) const override;
+    void renderHtml(std::ostream &os, RenderDocumentContext *rc) const override;
 
     /** @brief Render as text
      * @param os Output
+     * @param rc Rendering context
      */
-    void renderText(std::ostream &os) const override;
+    void renderText(std::ostream &os, RenderDocumentContext *rc) const override;
   };
 
   /** @brief A paragraph */
@@ -195,16 +202,18 @@ public:
     Paragraph(const std::string &s) {
       append(s);
     }
+
     /** @brief Render as HTML
      * @param os Output
-     * @param as Accumulator for attachments
+     * @param rc Rendering context
      */
-    void renderHtml(std::ostream &os, Attachments *as) const override;
+    void renderHtml(std::ostream &os, RenderDocumentContext *rc) const override;
 
     /** @brief Render as text
      * @param os Output
+     * @param rc Rendering context
      */
-    void renderText(std::ostream &os) const override;
+    void renderText(std::ostream &os, RenderDocumentContext *rc) const override;
   };
 
   /** @brief A verbatim section */
@@ -214,14 +223,15 @@ public:
 
     /** @brief Render as HTML
      * @param os Output
-     * @param as Accumulator for attachments
+     * @param rc Rendering context
      */
-    void renderHtml(std::ostream &os, Attachments *as) const override;
+    void renderHtml(std::ostream &os, RenderDocumentContext *rc) const override;
 
     /** @brief Render as text
      * @param os Output
+     * @param rc Rendering context
      */
-    void renderText(std::ostream &os) const override;
+    void renderText(std::ostream &os, RenderDocumentContext *rc) const override;
   };
 
   /** @brief Possible types of list */
@@ -243,14 +253,15 @@ public:
 
     /** @brief Render as HTML
      * @param os Output
-     * @param as Accumulator for attachments
+     * @param rc Rendering context
      */
-    void renderHtml(std::ostream &os, Attachments *as) const override;
+    void renderHtml(std::ostream &os, RenderDocumentContext *rc) const override;
 
     /** @brief Render as text
      * @param os Output
+     * @param rc Rendering context
      */
-    void renderText(std::ostream &os) const override;
+    void renderText(std::ostream &os, RenderDocumentContext *rc) const override;
 
     /** @brief List type */
     ListType type;
@@ -274,14 +285,15 @@ public:
 
     /** @brief Render as HTML
      * @param os Output
-     * @param as Accumulator for attachments
+     * @param rc Rendering context
      */
-    void renderHtml(std::ostream &os, Attachments *as) const override;
+    void renderHtml(std::ostream &os, RenderDocumentContext *rc) const override;
 
     /** @brief Render as text
      * @param os Output
+     * @param rc Rendering context
      */
-    void renderText(std::ostream &os) const override;
+    void renderText(std::ostream &os, RenderDocumentContext *rc) const override;
   };
 
   /** @brief A heading
@@ -316,34 +328,40 @@ public:
 
     /** @brief Render as HTML
      * @param os Output
-     * @param as Accumulator for attachments
+     * @param rc Rendering context
      */
-    void renderHtml(std::ostream &os, Attachments *as) const override;
+    void renderHtml(std::ostream &os, RenderDocumentContext *rc) const override;
 
     /** @brief Render as text
      * @param os Output
+     * @param rc Rendering context
      */
-    void renderText(std::ostream &os) const override;
+    void renderText(std::ostream &os, RenderDocumentContext *rc) const override;
   };
 
+  class Table;
+
   /** @brief A cell in a table.
    *
    * The origin (x=y=0) is at the top left.  Don't add overlapping cells to a
    * single table.
    */
-  struct Cell: public LinearContainer {
+  class Cell: public LinearContainer {
+  public:
     /** @brief Constructor
      * @param w_ Cell width
      * @param h_ Cell height
      */
-    Cell(int w_ = 1, int h_ = 1): heading(false), w(w_), h(h_) {}
+    Cell(int w_ = 1, int h_ = 1, bool heading_ = false):
+        heading(heading_), w(w_), h(h_) {}
 
     /** @brief Constructor
      * @param s Initial contents
      * @param w_ Cell width
      * @param h_ Cell height
      */
-    Cell(const std::string &s, int w_ = 1, int h_ = 1): Cell(w_, h_) {
+    Cell(const std::string &s, int w_ = 1, int h_ = 1, bool heading_ = false):
+        Cell(w_, h_, heading_) {
       append(new String(s));
     }
 
@@ -352,10 +370,44 @@ public:
      * @param w_ Cell width
      * @param h_ Cell height
      */
-    Cell(Node *n, int w_ = 1, int h_ = 1): Cell(w_, h_) {
+    Cell(Node *n, int w_ = 1, int h_ = 1, bool heading_ = false):
+        Cell(w_, h_, heading_) {
       append(n);
     }
 
+    /** @brief Render as HTML
+     * @param os Output
+     * @param rc Rendering context
+     */
+    void renderHtml(std::ostream &os, RenderDocumentContext *rc) const override;
+
+    /** @brief Render as text
+     * @param os Output
+     * @param rc Rendering context
+     */
+    void renderText(std::ostream &os, RenderDocumentContext *rc) const override;
+
+    bool getHeader() const {
+      return heading;
+    }
+
+    int getX() const {
+      return x;
+    }
+
+    int getY() const {
+      return y;
+    }
+
+    int getWidth() const {
+      return w;
+    }
+
+    int getHeight() const {
+      return h;
+    }
+
+  private:
     /** @brief True if this is a table heading */
     bool heading;
 
@@ -371,16 +423,7 @@ public:
     /** @brief Height in rows */
     int h;
 
-    /** @brief Render as HTML
-     * @param os Output
-     * @param as Accumulator for attachments
-     */
-    void renderHtml(std::ostream &os, Attachments *as) const override;
-
-    /** @brief Render as text
-     * @param os Output
-     */
-    void renderText(std::ostream &os) const override;
+    friend class Table;
   };
 
   /** @brief A table.
@@ -388,20 +431,20 @@ public:
    * The origin (x=y=0) is at the top left.  Don't add overlapping cells to a
    * single table.
    */
-  struct Table: public Node {
+  class Table: public Node {
+  public:
     /** @brief Destructor */
     ~Table() override;
 
-    // TODO we do a lot of O(n^2) passes over this; can we do better?
-
-    /** @brief List of cells */
-    std::vector<Cell *> cells;
-
     /** @brief Width of table (columns) */
-    int width() const;
+    int getWidth() const {
+      return width;
+    }
 
     /** @brief Height of table (rows) */
-    int height() const;
+    int getHeight() const {
+      return height;
+    }
 
     /** @brief Add a cell at the cursor
      * @param cell Cell to add
@@ -409,15 +452,6 @@ public:
      */
     Cell *addCell(Cell *cell);
 
-    /** @brief Add a heading cell at the cursor
-     * @param cell Cell to add
-     * @return @p cell
-     */
-    Cell *addHeadingCell(Cell *cell) {
-      cell->heading = true;
-      return addCell(cell);
-    }
-
     /** @brief Start a new row */
     void newRow();
 
@@ -433,25 +467,49 @@ public:
      * @param x X position
      * @param y Y position
      * @return @p cell or null pointer
+     *
+     * Note that this returns both cells located at x,y and also
+     * multi-column/row cells that extend to x,y.
      */
-    Cell *occupied(int x, int y) const;
+    const Cell *findOverlappingCell(int x, int y) const;
+
+    /** @brief Find the cell rooted at a position
+     * @param x X position
+     * @param y Y position
+     * @return @p cell or null pointer
+     *
+     * Note that this returns pm;u cells located at x,y, not also
+     * multi-column/row cells that extend to x,y.
+     */
+    const Cell *findRootedCell(int x, int y) const;
 
     /** @brief Render as HTML
      * @param os Output
-     * @param as Accumulator for attachments
+     * @param rc Rendering context
      */
-    void renderHtml(std::ostream &os, Attachments *as) const override;
+    void renderHtml(std::ostream &os, RenderDocumentContext *rc) const override;
 
     /** @brief Render as text
      * @param os Output
+     * @param rc Rendering context
      */
-    void renderText(std::ostream &os) const override;
+    void renderText(std::ostream &os, RenderDocumentContext *rc) const override;
 
+  private:
     /** @brief Cursor X position */
     int x = 0;
 
     /** @brief Cursor Y position */
     int y = 0;
+
+    /** @brief Current table width */
+    int width = 0;
+
+    /** @brief Current table height */
+    int height = 0;
+
+    /** @brief Map of x, y coordinate pairs to cells */
+    std::map<std::pair<int, int>, Cell *> cellMap;
   };
 
   /** @brief An image */
@@ -465,14 +523,15 @@ public:
 
     /** @brief Render as HTML
      * @param os Output
-     * @param as Accumulator for attachments
+     * @param rc Rendering context
      */
-    void renderHtml(std::ostream &os, Attachments *as) const override;
+    void renderHtml(std::ostream &os, RenderDocumentContext *rc) const override;
 
     /** @brief Render as text
      * @param os Output
+     * @param rc Rendering context
      */
-    void renderText(std::ostream &os) const override;
+    void renderText(std::ostream &os, RenderDocumentContext *rc) const override;
 
     /** @brief MIME type of image */
     std::string type;
@@ -488,14 +547,15 @@ public:
   struct RootContainer: public LinearContainer {
     /** @brief Render as HTML
      * @param os Output
-     * @param as Accumulator for attachments
+     * @param rc Rendering context
      */
-    void renderHtml(std::ostream &os, Attachments *as) const override;
+    void renderHtml(std::ostream &os, RenderDocumentContext *rc) const override;
 
     /** @brief Render as text
      * @param os Output
+     * @param rc Rendering context
      */
-    void renderText(std::ostream &os) const override;
+    void renderText(std::ostream &os, RenderDocumentContext *rc) const override;
   };
 
   /** @brief The content of the document */
@@ -535,14 +595,15 @@ public:
 
   /** @brief Render the document as HTML
    * @param os Output
-   * @param as Accumulator for attachments
+   * @param rc Rendering context
    */
-  void renderHtml(std::ostream &os, Attachments *as) const;
+  void renderHtml(std::ostream &os, RenderDocumentContext *rc) const;
 
   /** @brief Render the document as text
    * @param os Output
+   * @param rc Rendering context
    */
-  void renderText(std::ostream &os) const;
+  void renderText(std::ostream &os, RenderDocumentContext *rc) const;
 
   /** @brief HTML quoting */
   static void quoteHtml(std::ostream &os, const std::string &s);
@@ -552,11 +613,14 @@ public:
                            size_t indent = 0, bool indentFirst = true);
 };
 
-/** @brief Container for attachments accumulated during rendering */
-class Attachments {
+/** @brief Container for rendering */
+class RenderDocumentContext {
 public:
   /** @brief Accumulated images */
   std::vector<const Document::Image *> images;
+
+  /** @brief Page width */
+  int width = DEFAULT_TEXT_WIDTH;
 };
 
 #endif /* DOCUMENT_H */
