@@ -70,21 +70,17 @@ VolumeLabels::VolumeLabels(Render::Context &ctx): Render::Grid(ctx) {
   set_padding(globalConfig.horizontalPadding, globalConfig.verticalPadding);
 }
 
-DeviceKey::DeviceKey(Render::Context &ctx):
-  Render::Grid(ctx) {
+DeviceKey::DeviceKey(Render::Context &ctx): Render::Grid(ctx) {
   unsigned row = 0;
   for(auto device_iterator: globalConfig.devices) {
     const auto &device = device_iterator.first;
     device_rows[device] = row;
-    auto t = new Render::Text(ctx, device,
-                              globalConfig.colorGraphForeground,
+    auto t = new Render::Text(ctx, device, globalConfig.colorGraphForeground,
                               globalConfig.deviceNameFont);
     cleanup(t);
     add(t, 0, row);
-    auto r = new Render::Rectangle(ctx,
-                                   globalConfig.backupIndicatorKeyWidth,
-                                   indicator_height,
-                                   device_color(row));
+    auto r = new Render::Rectangle(ctx, globalConfig.backupIndicatorKeyWidth,
+                                   indicator_height, device_color(row));
     rectangles.push_back(r);
     cleanup(r);
     add(r, 1, row, -1, 0);
@@ -96,8 +92,7 @@ DeviceKey::DeviceKey(Render::Context &ctx):
 void DeviceKey::set_indicator_height(double h) {
   indicator_height = h;
   for(auto r: rectangles)
-    r->set_size(-1,
-                indicator_height);
+    r->set_size(-1, indicator_height);
 }
 
 const Color DeviceKey::device_color(unsigned row) const {
@@ -107,16 +102,14 @@ const Color DeviceKey::device_color(unsigned row) const {
   if(context.colors.find(di) != context.colors.end())
     return context.colors[di];
   */
-  return globalConfig.deviceColorStrategy->get(row, globalConfig.devices.size());
+  return globalConfig.deviceColorStrategy->get(row,
+                                               globalConfig.devices.size());
 }
 
 HistoryGraphContent::HistoryGraphContent(Render::Context &ctx,
                                          const DeviceKey &device_key):
-  Render::Widget(ctx),
-  earliest(INT_MAX, 1, 0),
-  latest(0),
-  device_key(device_key),
-  rows(0) {
+    Render::Widget(ctx),
+    earliest(INT_MAX, 1, 0), latest(0), device_key(device_key), rows(0) {
   for(auto host_iterator: globalConfig.hosts) {
     Host *host = host_iterator.second;
     if(!host->selected())
@@ -142,7 +135,7 @@ void HistoryGraphContent::set_extent() {
   assert(row_height > 0);
   auto columns = latest.toNumber() - earliest.toNumber() + 1;
   height = (rows ? row_height * rows + globalConfig.verticalPadding * (rows - 1)
-            : 0);
+                 : 0);
   width = latest >= earliest ? globalConfig.backupIndicatorWidth * columns : 0;
 }
 
@@ -174,8 +167,8 @@ void HistoryGraphContent::render_horizontal_guides() {
       Volume *volume = volume_iterator.second;
       if(!volume->selected())
         continue;
-      context.cairo->rectangle(0, row * (row_height + globalConfig.verticalPadding),
-                               width, 1);
+      context.cairo->rectangle(
+          0, row * (row_height + globalConfig.verticalPadding), width, 1);
       context.cairo->fill();
       set_source_color(globalConfig.colorVolumeGuide);
       ++row;
@@ -184,7 +177,7 @@ void HistoryGraphContent::render_horizontal_guides() {
   set_source_color(globalConfig.colorVolumeGuide);
   context.cairo->rectangle(0,
                            row * (row_height + globalConfig.verticalPadding)
-                             - globalConfig.verticalPadding,
+                               - globalConfig.verticalPadding,
                            width, 1);
   context.cairo->fill();
 }
@@ -192,8 +185,9 @@ void HistoryGraphContent::render_horizontal_guides() {
 void HistoryGraphContent::render_data() {
   double y = 0;
   double base = floor((row_height + globalConfig.verticalPadding - 1
-                       - (indicator_height
-                          * globalConfig.devices.size())) / 2) + 1;
+                       - (indicator_height * globalConfig.devices.size()))
+                      / 2)
+                + 1;
   for(auto host_iterator: globalConfig.hosts) {
     Host *host = host_iterator.second;
     if(!host->selected())
@@ -204,7 +198,8 @@ void HistoryGraphContent::render_data() {
         continue;
       for(auto backup: volume->backups) {
         if(backup->getStatus() == COMPLETE) {
-          double x = (Date(backup->time) - earliest) * globalConfig.backupIndicatorWidth;
+          double x = (Date(backup->time) - earliest)
+                     * globalConfig.backupIndicatorWidth;
           auto device_row = device_key.device_row(backup);
           double offset = base + device_row * indicator_height;
           set_source_color(device_key.device_color(backup));
@@ -225,10 +220,8 @@ void HistoryGraphContent::render() {
   render_data();
 }
 
-TimeLabels::TimeLabels(Render::Context &ctx,
-                       HistoryGraphContent &content): Render::Container(ctx),
-                                                      content(content) {
-}
+TimeLabels::TimeLabels(Render::Context &ctx, HistoryGraphContent &content):
+    Render::Container(ctx), content(content) {}
 
 void TimeLabels::set_extent() {
   if(width < 0) {
@@ -239,18 +232,14 @@ void TimeLabels::set_extent() {
       Date next = d;
       next.d = 1;
       next.addMonth();
-      double xnext = (next - content.earliest) * globalConfig.backupIndicatorWidth;
-      auto t = new Render::Text(context, "",
-                                globalConfig.colorGraphForeground,
+      double xnext =
+          (next - content.earliest) * globalConfig.backupIndicatorWidth;
+      auto t = new Render::Text(context, "", globalConfig.colorGraphForeground,
                                 globalConfig.timeLabelFont);
       cleanup(t);
       // Try increasingly compact formats until one fits
       static const char *const formats[] = {
-        "%B %Y",
-        "%b %Y",
-        "%b %y",
-        "%B",
-        "%b",
+          "%B %Y", "%b %Y", "%b %y", "%B", "%b",
       };
       static const unsigned nformats = sizeof formats / sizeof *formats;
       unsigned format;
@@ -277,12 +266,8 @@ void TimeLabels::set_extent() {
 }
 
 HistoryGraph::HistoryGraph(Render::Context &ctx):
-  Render::Grid(ctx),
-  host_labels(ctx),
-  volume_labels(ctx),
-  device_key(ctx),
-  content(ctx, device_key),
-  time_labels(ctx, content) {
+    Render::Grid(ctx), host_labels(ctx), volume_labels(ctx), device_key(ctx),
+    content(ctx, device_key), time_labels(ctx, content) {
   set_padding(globalConfig.horizontalPadding, globalConfig.verticalPadding);
 }
 
@@ -290,11 +275,10 @@ void HistoryGraph::set_extent() {
   host_labels.set_extent();
   volume_labels.set_extent();
   device_key.set_extent();
-  //time_labels.set_extent();
-  double row_height = std::max({host_labels.get_maximum_height(),
-        volume_labels.get_maximum_height(),
-        (globalConfig.backupIndicatorHeight
-         * globalConfig.devices.size())});
+  // time_labels.set_extent();
+  double row_height = std::max(
+      {host_labels.get_maximum_height(), volume_labels.get_maximum_height(),
+       (globalConfig.backupIndicatorHeight * globalConfig.devices.size())});
   double indicator_height = floor(row_height / globalConfig.devices.size());
   device_key.set_indicator_height(indicator_height);
   content.set_indicator_height(indicator_height);
@@ -306,11 +290,12 @@ void HistoryGraph::set_extent() {
 }
 
 void HistoryGraph::addPart(const std::string &partspec) {
-  static std::regex
-    partspec_regex("^([^:]+):([0-9]+),([0-9]+)(?::([LCR])([TCB]))?$");
+  static std::regex partspec_regex(
+      "^([^:]+):([0-9]+),([0-9]+)(?::([LCR])([TCB]))?$");
   std::smatch mr;
   if(!std::regex_match(partspec, mr, partspec_regex))
-    throw SyntaxError("invalid graph component specification '" + partspec + "'");
+    throw SyntaxError("invalid graph component specification '" + partspec
+                      + "'");
   std::string part = mr[1];
   unsigned column = parseInteger(mr[2], 0, std::numeric_limits<int>::max());
   unsigned row = parseInteger(mr[3], 0, std::numeric_limits<int>::max());
@@ -328,12 +313,18 @@ void HistoryGraph::addPart(const std::string &partspec) {
   default: throw std::logic_error("HistoryGraph::addPart vj");
   }
   Widget *w;
-  if(part == "host-labels") w = &host_labels;
-  else if(part == "volume-labels") w = &volume_labels;
-  else if(part == "content") w = &content;
-  else if(part == "time-labels") w = &time_labels;
-  else if(part == "device-key") w = &device_key;
-  else throw SyntaxError("unrecognized graph component '" + part + "'");
+  if(part == "host-labels")
+    w = &host_labels;
+  else if(part == "volume-labels")
+    w = &volume_labels;
+  else if(part == "content")
+    w = &content;
+  else if(part == "time-labels")
+    w = &time_labels;
+  else if(part == "device-key")
+    w = &device_key;
+  else
+    throw SyntaxError("unrecognized graph component '" + part + "'");
   add(w, column, row, hj, vj);
 }
 
@@ -354,7 +345,8 @@ void HistoryGraph::adjustConfig() {
     return;
 
   // Figure out how big a content panel we can get away with
-  double maxContentWidth = globalConfig.graphTargetWidth - (width - content.width);
+  double maxContentWidth =
+      globalConfig.graphTargetWidth - (width - content.width);
   maxContentWidth = floor(maxContentWidth);
   auto columns = content.latest.toNumber() - content.earliest.toNumber() + 1;
 
@@ -369,17 +361,18 @@ void HistoryGraph::adjustConfig() {
   if(width < globalConfig.graphTargetWidth) {
     // We can make the indicators bigger
     // Pick the biggest
-    globalConfig.backupIndicatorWidth = std::max(globalConfig.backupIndicatorWidth,
-                                                 maxIndicatorWidth);
+    globalConfig.backupIndicatorWidth =
+        std::max(globalConfig.backupIndicatorWidth, maxIndicatorWidth);
     content.changed();
     return;
   }
-  if(globalConfig.graphTargetWidth > 0 && width > globalConfig.graphTargetWidth) {
+  if(globalConfig.graphTargetWidth > 0
+     && width > globalConfig.graphTargetWidth) {
     // We have exceeded the target width
     if(maxContentWidth <= 0) {
       // User has asked for the impossible
       warning(WARNING_ALWAYS, "graph-target-width is much too small");
-      return;                           // Oh well
+      return; // Oh well
     }
     globalConfig.backupIndicatorWidth = maxIndicatorWidth;
     content.changed();
