@@ -33,19 +33,13 @@ public:
   PruneDecay(): PrunePolicy("decay") {}
 
   void validate(const Volume *volume) const override {
-    if(parseTimeInterval(get(volume, "decay-start", DEFAULT_DECAY_START), 86400,
-                         std::numeric_limits<int>::max())
-       < 1)
+    if(parseTimeInterval(get(volume, "decay-start", DEFAULT_DECAY_START)) < 1)
       throw SyntaxError("decay-start too small");
-    if(parseTimeInterval(get(volume, "decay-window", DEFAULT_DECAY_WINDOW),
-                         86400, std::numeric_limits<int>::max())
-       < 1)
+    if(parseTimeInterval(get(volume, "decay-window", DEFAULT_DECAY_WINDOW)) < 1)
       throw SyntaxError("decay-window too small");
     parseFloat(get(volume, "decay-scale", DEFAULT_DECAY_SCALE), 1,
                std::numeric_limits<double>::max(), ExclusiveLimit);
-    if(parseTimeInterval(get(volume, "decay-limit", DEFAULT_PRUNE_AGE), 86400,
-                         std::numeric_limits<int>::max())
-       < 1)
+    if(parseTimeInterval(get(volume, "decay-limit", DEFAULT_PRUNE_AGE)) < 1)
       throw SyntaxError("decay-limit too small");
   }
 
@@ -53,19 +47,16 @@ public:
                 std::map<Backup *, std::string> &prune, int) const override {
     const Volume *volume = onDevice.at(0)->volume;
     int decayStart =
-        parseTimeInterval(get(volume, "decay-start", DEFAULT_DECAY_START),
-                          86400, std::numeric_limits<int>::max())
+        parseTimeInterval(get(volume, "decay-start", DEFAULT_DECAY_START))
         / 86400;
     int decayWindow =
-        parseTimeInterval(get(volume, "decay-window", DEFAULT_DECAY_WINDOW),
-                          86400, std::numeric_limits<int>::max())
+        parseTimeInterval(get(volume, "decay-window", DEFAULT_DECAY_WINDOW))
         / 86400;
     double decayScale =
         parseFloat(get(volume, "decay-scale", DEFAULT_DECAY_SCALE), 1,
                    std::numeric_limits<double>::max(), ExclusiveLimit);
     int decayLimit =
-        parseTimeInterval(get(volume, "decay-limit", DEFAULT_PRUNE_AGE), 86400,
-                          std::numeric_limits<int>::max())
+        parseTimeInterval(get(volume, "decay-limit", DEFAULT_PRUNE_AGE))
         / 86400;
     if(onDevice.size() == 1)
       return;
