@@ -21,17 +21,20 @@
 #include <cstdio>
 #include <cstdarg>
 
-void Document::LinearContainer::renderTextContents(std::ostream &os) const {
+void Document::LinearContainer::renderTextContents(
+    std::ostream &os, RenderDocumentContext *rc) const {
   for(auto &node: nodes)
-    node->renderText(os);
+    node->renderText(os, rc);
 }
 
-void Document::String::renderText(std::ostream &os) const {
+void Document::String::renderText(std::ostream &os,
+                                  RenderDocumentContext *) const {
   os << text;
 }
 
-void Document::LinearContainer::renderText(std::ostream &os) const {
-  renderTextContents(os);
+void Document::LinearContainer::renderText(std::ostream &os,
+                                           RenderDocumentContext *rc) const {
+  renderTextContents(os, rc);
 }
 
 void Document::wordWrapText(std::ostream &os, const std::string &s,
@@ -70,24 +73,28 @@ void Document::wordWrapText(std::ostream &os, const std::string &s,
     os << '\n';
 }
 
-void Document::Paragraph::renderText(std::ostream &os) const {
+void Document::Paragraph::renderText(std::ostream &os,
+                                     RenderDocumentContext *rc) const {
   // Convert to a single string
   std::stringstream ss;
-  renderTextContents(ss);
-  wordWrapText(os, ss.str(), 80); // TODO configurable width
+  renderTextContents(ss, rc);
+  wordWrapText(os, ss.str(), rc ? rc->width : DEFAULT_TEXT_WIDTH);
   os << '\n';
 }
 
-void Document::Verbatim::renderText(std::ostream &os) const {
-  renderTextContents(os);
+void Document::Verbatim::renderText(std::ostream &os,
+                                    RenderDocumentContext *rc) const {
+  renderTextContents(os, rc);
   os << '\n';
 }
 
-void Document::List::renderText(std::ostream &os) const {
+void Document::List::renderText(std::ostream &os,
+                                RenderDocumentContext *rc) const {
+  const size_t width = rc ? rc->width : DEFAULT_TEXT_WIDTH;
   for(size_t n = 0; n < nodes.size(); ++n) {
     char prefix[64];
     std::stringstream ss;
-    nodes[n]->renderText(ss);
+    nodes[n]->renderText(ss, rc);
     switch(type) {
     case OrderedList:
       snprintf(prefix, sizeof prefix, " %zu. ", n + 1);
@@ -96,34 +103,36 @@ void Document::List::renderText(std::ostream &os) const {
     case UnorderedList: strcpy(prefix, " * "); break;
     }
     os << prefix;
-    wordWrapText(os, ss.str(), 80 - strlen(prefix), strlen(prefix), false);
+    wordWrapText(os, ss.str(), width - strlen(prefix), strlen(prefix), false);
   }
   os << '\n';
 }
 
-void Document::ListEntry::renderText(std::ostream &os) const {
-  renderTextContents(os);
+void Document::ListEntry::renderText(std::ostream &os,
+                                     RenderDocumentContext *rc) const {
+  renderTextContents(os, rc);
 }
 
-void Document::Heading::renderText(std::ostream &os) const {
+void Document::Heading::renderText(std::ostream &os,
+                                   RenderDocumentContext *rc) const {
   if(level > 6)
     throw std::runtime_error("heading level too high");
   switch(level) {
   case 1:
     os << "==== ";
-    renderTextContents(os);
+    renderTextContents(os, rc);
     os << " ====";
     os << '\n';
     break;
   case 2:
     os << "=== ";
-    renderTextContents(os);
+    renderTextContents(os, rc);
     os << " ===";
     os << '\n';
     break;
   case 3:
     os << "== ";
-    renderTextContents(os);
+    renderTextContents(os, rc);
     os << " ==";
     os << '\n';
     break;
@@ -131,29 +140,30 @@ void Document::Heading::renderText(std::ostream &os) const {
   case 5:
   case 6:
     os << "* ";
-    renderTextContents(os);
+    renderTextContents(os, rc);
     os << '\n';
     break;
   }
   os << '\n';
 }
 
-void Document::Cell::renderText(std::ostream &os) const {
-  renderTextContents(os);
+void Document::Cell::renderText(std::ostream &os,
+                                RenderDocumentContext *rc) const {
+  renderTextContents(os, rc);
 }
 
-void Document::Table::renderText(std::ostream &os) const {
+void Document::Table::renderText(std::ostream &os,
+                                 RenderDocumentContext *rc) const {
   // First pass: compute column widths based on single-column cells
-  const int tableColumns = width(), tableRows = height();
   std::vector<size_t> columnWidths;
-  for(int xpos = 0; xpos < tableColumns; ++xpos) {
+  for(int xpos = 0; xpos < width; ++xpos) {
     size_t columnWidth = 0;
-    for(int ypos = 0; ypos < tableRows; ++ypos) {
-      Cell *cell = occupied(xpos, ypos);
+    for(int ypos = 0; ypos < height; ++ypos) {
+      const Cell *cell = findOverlappingCell(xpos, ypos);
       // We only consider single-width cells
-      if(cell && cell->w == 1) {
+      if(cell && cell->getWidth() == 1) {
         std::stringstream ss;
-        cell->renderText(ss);
+        cell->renderText(ss, rc);
         size_t w = ss.str().size();
         if(w > columnWidth)
           columnWidth = w;
@@ -162,15 +172,15 @@ void Document::Table::renderText(std::ostream &os) const {
     columnWidths.push_back(columnWidth);
   }
   // Second pass: add extra space to accomodate multiple-column cells
-  for(int xpos = 0; xpos < tableColumns; ++xpos) {
-    for(int ypos = 0; ypos < tableRows; ++ypos) {
-      Cell *cell = occupied(xpos, ypos);
-      if(cell && cell->x == xpos && cell->w > 1) {
+  for(int xpos = 0; xpos < width; ++xpos) {
+    for(int ypos = 0; ypos < height; ++ypos) {
+      const Cell *cell = findOverlappingCell(xpos, ypos);
+      if(cell && cell->getX() == xpos && cell->getWidth() > 1) {
         std::stringstream ss;
-        cell->renderText(ss);
+        cell->renderText(ss, rc);
         // Determine the space available
-        size_t availableWidth = 3 * (cell->w - 1);
-        for(int i = 0; i < cell->w; ++i)
+        size_t availableWidth = 3 * (cell->getWidth() - 1);
+        for(int i = 0; i < cell->getWidth(); ++i)
           availableWidth += columnWidths[xpos + i];
         if(ss.str().size() <= availableWidth)
           continue;
@@ -181,24 +191,24 @@ void Document::Table::renderText(std::ostream &os) const {
   }
   // We lay out as | <data> | <data> | ... |
   // Third pass: render the table
-  for(int ypos = 0; ypos < tableRows; ++ypos) {
-    for(int xpos = 0; xpos < tableColumns; ++xpos) {
-      Cell *cell = occupied(xpos, ypos);
+  for(int ypos = 0; ypos < height; ++ypos) {
+    for(int xpos = 0; xpos < width; ++xpos) {
+      const Cell *cell = findOverlappingCell(xpos, ypos);
       if(cell) {
-        if(cell->y == ypos) {
-          if(cell->x == xpos) {
+        if(cell->getY() == ypos) {
+          if(cell->getX() == xpos) {
             // First row/column of the cell
             // Determine the space available
-            size_t availableWidth = 3 * (cell->w - 1);
-            for(int i = 0; i < cell->w; ++i)
+            size_t availableWidth = 3 * (cell->getWidth() - 1);
+            for(int i = 0; i < cell->getWidth(); ++i)
               availableWidth += columnWidths[xpos + i];
             if(xpos)
               os << ' ';
             os << "| ";
             std::stringstream ss;
-            cell->renderText(ss);
+            cell->renderText(ss, rc);
             size_t left = availableWidth - ss.str().size();
-            if(cell->heading) {
+            if(cell->getHeader()) {
               for(size_t i = 0; i < left / 2; ++i)
                 os << ' ';
               left -= left / 2;
@@ -233,12 +243,14 @@ void Document::Table::renderText(std::ostream &os) const {
   os << '\n';
 }
 
-void Document::Image::renderText(std::ostream &) const {}
+void Document::Image::renderText(std::ostream &,
+                                 RenderDocumentContext *) const {}
 
-void Document::RootContainer::renderText(std::ostream &os) const {
-  renderTextContents(os);
+void Document::RootContainer::renderText(std::ostream &os,
+                                         RenderDocumentContext *rc) const {
+  renderTextContents(os, rc);
 }
 
-void Document::renderText(std::ostream &os) const {
-  content.renderText(os);
+void Document::renderText(std::ostream &os, RenderDocumentContext *rc) const {
+  content.renderText(os, rc);
 }
