@@ -1,4 +1,4 @@
-// Copyright © 2011, 2012, 2014, 2015 Richard Kettlewell.
+// Copyright © Richard Kettlewell.
 //
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -23,6 +23,10 @@
 // or outside [min,max].
 long long parseInteger(const std::string &s, long long min, long long max,
                        int radix) {
+  // strtoll is a bit loose and accepts e.g. initial whitespace, which we don't
+  // want.
+  if(s.size() > 0 && !((s.at(0) >= '0' && s.at(0) <= '9') || s.at(0) == '-'))
+    throw SyntaxError("invalid integer '" + s + "'");
   errno = 0;
   const char *sc = s.c_str();
   char *e;
