@@ -154,19 +154,38 @@ absent() {
 
 s() {
   echo ">" "$@" "#" ${RSBACKUP_TIME} >&2
-  if [ -z "$STDERR" ]; then
-    if [ -z "${RSBACKUP_TIME}" ]; then
-      RUN="${RUN}" "$@"
-    else
-      RUN="${RUN}" RSBACKUP_TIME="${RSBACKUP_TIME}" "$@"
-    fi
+  if [ "$STDOUT" != "" ]; then
+    exec 3>&1
+    exec >"$STDOUT"
+  fi
+  if [ "$STDERR" != "" ]; then
+    exec 4>&2
+    exec 2>"$STDERR"
+  fi
+  ok=true
+  if RUN="${RUN}" RSBACKUP_TIME="${RSBACKUP_TIME}" "$@"; then
+    ok=true
   else
-    if "$@" 2> "$STDERR"; then
-      cat "$STDERR" >&2
-    else
-      cat "$STDERR" >&2
-      false
-    fi
+    ok=false
+  fi
+  if [ "$STDOUT" != "" ]; then
+    exec 1>&3
+    cat "$STDOUT" >&1
+  fi
+  if [ "$STDERR" != "" ]; then
+    exec 2>&4
+    cat "$STDERR" >&2
+  fi
+  ${ok}
+}
+
+fails() {
+  echo ">" "$@" "#" ${RSBACKUP_TIME} >&2
+  if "$@"; then
+    echo "# unexpectedly succeeded" >&2
+    false
+  else
+    echo "# failed as expected" >&2
   fi
 }
 
